@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Accessor;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Accessor::VERSION = '1.100980';
+}
 # ABSTRACT: Construct framework-specific accessors
 use Error::Hierarchy::Util 'assert_read_only';
 use Class::Scaffold::Factory::Type;
@@ -56,7 +58,7 @@ Class::Scaffold::Accessor - Construct framework-specific accessors
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -109,11 +111,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
