@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::App::CommandLine;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::App::CommandLine::VERSION = '1.100980';
+}
 # ABSTRACT: Base class for command line-based framework applications
 use Class::Scaffold::Environment;
 use Property::Lookup;
@@ -37,7 +39,7 @@ Class::Scaffold::App::CommandLine - Base class for command line-based framework
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 INSTALLATION
 
@@ -57,11 +59,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
