@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::App::Test::Class;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::App::Test::Class::VERSION = '1.100980';
+}
 # ABSTRACT: Base class for Test::Class-based test programs
 use parent qw(Class::Scaffold::App::CommandLine Test::Class::GetoptControl);
 use constant GETOPT => qw(
@@ -28,7 +30,7 @@ Class::Scaffold::App::Test::Class - Base class for Test::Class-based test progra
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 INSTALLATION
 
@@ -48,11 +50,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
