@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::App::Test::YAMLDriven;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::App::Test::YAMLDriven::VERSION = '1.100980';
+}
 # ABSTRACT: Base class for YAML-driven test programs
 use Class::Scaffold::App;
 use Error::Hierarchy::Util 'assert_defined';
@@ -211,7 +213,7 @@ Class::Scaffold::App::Test::YAMLDriven - Base class for YAML-driven test program
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -265,11 +267,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
