@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Base_TEST;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Base_TEST::VERSION = '1.100980';
+}
 # ABSTRACT: Test companion class for the general base class
 use Error::Hierarchy::Test 'throws2_ok';
 use Test::More;
@@ -42,7 +44,7 @@ Class::Scaffold::Base_TEST - Test companion class for the general base class
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -68,11 +70,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
