@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::BusinessObject;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::BusinessObject::VERSION = '1.100980';
+}
 # ABSTRACT: Base class for framework business objects
 use Error::Hierarchy::Util 'assert_defined';
 use parent qw(
@@ -54,7 +56,7 @@ Class::Scaffold::BusinessObject - Base class for framework business objects
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -113,11 +115,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
