@@ -3,12 +3,14 @@ use warnings;
 use strict;
 
 package Class::Scaffold::ConstantImporter;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::ConstantImporter::VERSION = '1.100980';
+}
 # ABSTRACT: Import environment constants as simple functions
 use Devel::Caller qw(caller_args);
 
 sub import {
-    my $pkg     = shift;
+    shift;  # we don't need the package name
     my $callpkg = caller(0);
     no strict 'refs';
 
@@ -51,7 +53,7 @@ Class::Scaffold::ConstantImporter - Import environment constants as simple funct
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 INSTALLATION
 
@@ -71,11 +73,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
