@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Context;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Context::VERSION = '1.100980';
+}
 # ABSTRACT: Holds execution and job context
 use parent 'Class::Scaffold::Base';
 __PACKAGE__->mk_scalar_accessors(qw(execution job));
@@ -42,7 +44,7 @@ Class::Scaffold::Context - Holds execution and job context
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -74,11 +76,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
