@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Delegate::Mixin;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Delegate::Mixin::VERSION = '1.100980';
+}
 # ABSTRACT: Mixin that provides access to the framework environment
 
 # Class::Scaffold::Base inherits from this mixin, so we shouldn't use()
@@ -26,7 +28,7 @@ Class::Scaffold::Delegate::Mixin - Mixin that provides access to the framework e
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -52,11 +54,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
