@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Environment_TEST;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Environment_TEST::VERSION = '1.100980';
+}
 # ABSTRACT: Companion test class for the framework environment base class
 use Error::Hierarchy::Test 'throws2_ok';
 use Test::More;
@@ -29,7 +31,7 @@ Class::Scaffold::Environment_TEST - Companion test class for the framework envir
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 INSTALLATION
 
@@ -49,11 +51,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
