@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Exception;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Exception::VERSION = '1.100980';
+}
 # ABSTRACT: Base class for framework exceptions
 
 # It's ok to inherit from Class::Scaffold::Storable as well; new() will be
@@ -26,7 +28,7 @@ Class::Scaffold::Exception - Base class for framework exceptions
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 INSTALLATION
 
@@ -46,11 +48,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
