@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Exception::Business;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Exception::Business::VERSION = '1.100980';
+}
 
 # ABSTRACT: Differentiate business exceptions from internal exceptions
 use warnings;
@@ -20,7 +22,7 @@ Class::Scaffold::Exception::Business - Differentiate business exceptions from in
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 INSTALLATION
 
@@ -40,11 +42,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
