@@ -3,8 +3,10 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Exception::NoSuchFactoryHandler;
-our $VERSION = '1.100810';
-# ABSTRACT: Exception raised on a factory lookup failure
+BEGIN {
+  $Class::Scaffold::Exception::NoSuchFactoryHandler::VERSION = '1.100980';
+}
+# ABSTRACT: Exception raised on a factory look-up failure
 use parent 'Class::Scaffold::Exception';
 __PACKAGE__->mk_accessors(qw(handler_type spec));
 use constant default_message =>
@@ -29,11 +31,11 @@ __END__
 
 =head1 NAME
 
-Class::Scaffold::Exception::NoSuchFactoryHandler - Exception raised on a factory lookup failure
+Class::Scaffold::Exception::NoSuchFactoryHandler - Exception raised on a factory look-up failure
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 INSTALLATION
 
@@ -53,11 +55,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
