@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Exception::Util;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Exception::Util::VERSION = '1.100980';
+}
 # ABSTRACT: Helper functions for raising common exceptions
 use Error::Hierarchy::Util 'assert_class';
 use Exporter qw(import);
@@ -32,7 +34,7 @@ Class::Scaffold::Exception::Util - Helper functions for raising common exception
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -58,11 +60,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
