@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Factory;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Factory::VERSION = '1.100980';
+}
 # ABSTRACT: Base class for framework factories
 use Error;    # to get $Error::Depth;
 use Error::Hierarchy::Util qw/assert_defined load_class/;
@@ -62,7 +64,7 @@ Class::Scaffold::Factory - Base class for framework factories
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -96,11 +98,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
