@@ -3,12 +3,15 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Factory::Type;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Factory::Type::VERSION = '1.100980';
+}
 # ABSTRACT: Factory for framework object types
 use parent 'Class::Factory::Enhanced';
 
 sub import {
-    my ($class, $spec) = @_;
+    shift;   # We don't need the package name
+    my $spec = shift;
     return unless defined $spec && $spec eq ':all';
     my $pkg = caller;
     for my $symbol (Class::Scaffold::Factory::Type->get_registered_types) {
@@ -51,7 +54,7 @@ Class::Scaffold::Factory::Type - Factory for framework object types
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -85,11 +88,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
