@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::HierarchicalDirty;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::HierarchicalDirty::VERSION = '1.100980';
+}
 
 # ABSTRACT: Mixin that multiplexes the dirty flag among its subobjects
 
@@ -52,7 +54,7 @@ Class::Scaffold::HierarchicalDirty - Mixin that multiplexes the dirty flag among
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 DESCRIPTION
 
@@ -91,11 +93,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
