@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Introspect;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Introspect::VERSION = '1.100980';
+}
 # ABSTRACT: Find configuration files within the framework
 use FindBin '$Bin';
 use Cwd;
@@ -70,7 +72,7 @@ Class::Scaffold::Introspect - Find configuration files within the framework
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -100,11 +102,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
