@@ -3,14 +3,18 @@ use warnings;
 use strict;
 
 package Class::Scaffold::LazyString;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::LazyString::VERSION = '1.100980';
+}
 # ABSTRACT: Provides a string that is evaluated lazily
 use Exporter qw(import);
 our @EXPORT  = qw(lazy_string);
 sub lazy_string { bless { code => shift }, 'Class::Scaffold::LazyString::Code' }
 
 package Class::Scaffold::LazyString::Code;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::LazyString::Code::VERSION = '1.100980';
+}
 use overload '""' => sub { $_[0]->{code}->() };
 1;
 
@@ -24,7 +28,7 @@ Class::Scaffold::LazyString - Provides a string that is evaluated lazily
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -50,11 +54,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
