@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Log;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Log::VERSION = '1.100980';
+}
 # ABSTRACT: Logging utilities
 use Carp;
 use IO::File;
@@ -124,15 +126,15 @@ sub fatal {
 __END__
 =pod
 
+=for stopwords logdate precdate
+
 =head1 NAME
 
 Class::Scaffold::Log - Logging utilities
 
 =head1 VERSION
 
-version 1.100810
-
-=for stopwords logdate precdate
+version 1.100980
 
 =head1 METHODS
 
@@ -182,11 +184,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
