@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Storable;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Storable::VERSION = '1.100980';
+}
 
 # ABSTRACT: Base class for all framework classes that support a storage.
 use parent 'Class::Scaffold::Base';
@@ -114,7 +116,7 @@ Class::Scaffold::Storable - Base class for all framework classes that support a
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -144,11 +146,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
