@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Test;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Test::VERSION = '1.100980';
+}
 # ABSTRACT: Base classes for framework test classes
 use Test::More;
 use Class::Value;    # see run() below
@@ -54,7 +56,7 @@ Class::Scaffold::Test - Base classes for framework test classes
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -88,11 +90,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
