@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Test::Inherited;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Test::Inherited::VERSION = '1.100980';
+}
 # ABSTRACT: Base class for tests shared between framework distributions
 use parent 'Class::Scaffold::Base';
 sub INHERITED_TEST_CLASSES { () }
@@ -24,7 +26,7 @@ Class::Scaffold::Test::Inherited - Base class for tests shared between framework
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -54,11 +56,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
