@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::Test::UtilLoader;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::Test::UtilLoader::VERSION = '1.100980';
+}
 # ABSTRACT: Load other classes necessary for tests
 use Class::Scaffold::YAML::Marshall::Constant;
 use Class::Scaffold::YAML::Marshall::ExceptionContainer;
@@ -25,7 +27,7 @@ Class::Scaffold::Test::UtilLoader - Load other classes necessary for tests
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 DESCRIPTION
 
@@ -53,11 +55,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
