@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::YAML::Active;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::YAML::Active::VERSION = '1.100980';
+}
 # ABSTRACT: Base class for YAML::Active plugins
 use parent 'Class::Scaffold::Storable';
 1;
@@ -17,7 +19,7 @@ Class::Scaffold::YAML::Active - Base class for YAML::Active plugins
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 INSTALLATION
 
@@ -37,11 +39,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
