@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::YAML::Active::Array;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::YAML::Active::Array::VERSION = '1.100980';
+}
 # ABSTRACT: Base class for array-based YAML::Active plugins
 use parent qw(
   Class::Scaffold::Storable
@@ -20,7 +22,7 @@ Class::Scaffold::YAML::Active::Array - Base class for array-based YAML::Active p
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 INSTALLATION
 
@@ -40,11 +42,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
