@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::YAML::Active::Constant;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::YAML::Active::Constant::VERSION = '1.100980';
+}
 # ABSTRACT: Plugin to get framework environment constants
 use parent 'Class::Scaffold::YAML::Active';
 use YAML::Active qw/assert_hashref hash_activate/;
@@ -27,7 +29,7 @@ Class::Scaffold::YAML::Active::Constant - Plugin to get framework environment co
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -53,11 +55,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
