@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::YAML::Active::ExceptionContainer;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::YAML::Active::ExceptionContainer::VERSION = '1.100980';
+}
 # ABSTRACT: Plugin that constructs an exception container
 use YAML::Active qw/assert_arrayref array_activate/;
 use parent 'Class::Scaffold::YAML::Active';
@@ -41,7 +43,7 @@ Class::Scaffold::YAML::Active::ExceptionContainer - Plugin that constructs an ex
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -67,11 +69,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
