@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::YAML::Marshall;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::YAML::Marshall::VERSION = '1.100980';
+}
 # ABSTRACT: Base class for marshalling plugins to YAML
 
 # So that we get a delegate() method
@@ -19,7 +21,7 @@ Class::Scaffold::YAML::Marshall - Base class for marshalling plugins to YAML
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 INSTALLATION
 
@@ -39,11 +41,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
