@@ -3,7 +3,9 @@ use warnings;
 use strict;
 
 package Class::Scaffold::YAML::Marshall::Constant;
-our $VERSION = '1.100810';
+BEGIN {
+  $Class::Scaffold::YAML::Marshall::Constant::VERSION = '1.100980';
+}
 # ABSTRACT: Marshalling plugin to get framework environment constants
 use YAML::Marshall 'constant';
 use parent 'Class::Scaffold::YAML::Marshall';
@@ -26,7 +28,7 @@ Class::Scaffold::YAML::Marshall::Constant - Marshalling plugin to get framework
 
 =head1 VERSION
 
-version 1.100810
+version 1.100980
 
 =head1 METHODS
 
@@ -52,11 +54,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Class-Scaffold/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
